@@ -7,6 +7,9 @@
 # Флаг работы в Jupiter Notebook
 self.jupiter
 
+# Флаг гостевого пользователя при беспарольной авторизации
+self.is_guest
+
 # Текст ошибки присвается в случае аварийного завершения работы; может быть удобно при работе в Jupiter Notebook
 self.current_exception
 
