@@ -2,11 +2,41 @@
 # -*- coding: utf-8 -*-
 """ Модуль обработки ошибок из ответа """
 
+from multiprocessing.sharedctypes import Value
 import re
 import requests
 import datetime
 from typing import Dict, Union, Callable
-from .common import MONTHS, WEEK_DAYS, datetime_type, FUNCS, LOGIC_FUNCS
+from .common import datetime_type, \
+    MONTHS, WEEK_DAYS, FUNCS, LOGIC_FUNCS, UPDATE_TYPES, WEEK, UPDATE_PERIOD, INTERVAL_MAP
+
+
+def check_types() -> Callable:
+    """
+    Проверка полей на типы.
+    """
+    types_map = {
+        int: "int", float: "float", bool: "bool", str: "str", list: "list", dict: "dict", set: "set", tuple: "tuple"
+    }
+    def check_type_impl(field_info: list):
+        """
+            Возвращает ошибку ValueError, если параметр имеет тип, отличный от указанного.
+            :param field_info: (list) имеет вид: ["param_name", "param_value", "field_type", "default_value"].
+        """
+        param_name, param_value, field_type, *default_value = field_info
+        if not isinstance(param_value, field_type):
+            # значения по-умолчанию не считаем ошибкой, а потому этот кейс пропускаем
+            if default_value and default_value[0] == param_value:
+                return
+            if isinstance(field_type, tuple):
+                type_msg = '['
+                for ft in field_type:
+                    type_msg += '"{}", '.format(types_map.get(ft, str(ft)))
+                type_msg = type_msg[:-2] + '] types'
+            else:
+                type_msg = '"{}" type'.format(types_map.get(field_type, str(field_type)))
+            raise ValueError('Param "{}" must be {}!'.format(param_name, type_msg))
+    return check_type_impl
 
 
 def request_asserts(response: Dict, r: requests.models.Response) -> bool:
@@ -291,62 +321,108 @@ def checks(self, func_name: str, *args):
         return True
     elif func_name == "create_sphere":
         if len(args) == 1:
-            i = args[0]
             # проверка есть ли в названиях размерностей и фактов метка порядка байтов U + FEFF Byte Order МАРК (BOM)
-            if "\ufeff" in i["name"]:
-                raise ValueError("Измените кодировку исходного файла на UTF-8 без BOM!")
-            if "\ufeff" in i["db_field"]:
+            i, search_str = args[0], "\ufeff"
+            if search_str in i.get("name", str()) or search_str in i.get("db_field", str()):
                 raise ValueError("Измените кодировку исходного файла на UTF-8 без BOM!")
             return True
 
-        update_params, updates, file_type, sql_params, user_interval, interval, period, week, time_zones, source_name,\
-            cube_name = args[0], args[1], args[2], args[3], args[4], args[5], args[6], args[7], args[8], args[9],\
-            args[10]
+        update_params, file_type, sql_params, user_interval, source_name, cube_name, \
+            time_zones, increment_dim, interval_dim, interval_borders, date_format = args
+
+        def check_time(time: str) -> bool:
+            """
+            Проверка формата времени.
+            Вернёт True, если формат времени задан неправильно, иначе False.
+            """
+            try:
+                splitted_time = time.split(':')
+                datetime.time(int(splitted_time[0]), int(splitted_time[1]))
+            except Exception:
+                return True
+            return False
+
+        def get_date(date: str) -> datetime:
+            """
+            Возвращает дату объекта datetime по строковому формату даты.
+            Если преобразование строковой даты по заданному формату невозможно - будет сгенерирована ошибка.
+            """
+            try:
+                res = datetime.datetime.strptime(date, date_format)
+            except ValueError:
+                raise
+            return res
 
         # проверка, что создается мультисфера с уникальным названием
         if "not found" not in self.get_cube_without_creating_module(cube_name):
-            raise ValueError("Multisphere %s already exists!" % cube_name)
+            raise ValueError('Multisphere "{}" already exists!'.format(cube_name))
 
+        # проверка длины названия мультисферы
         if len(cube_name) < 5:
             raise ValueError("Название мультисферы должно состоять из 5 и более символов!")
 
-        # проверка заданного вида обновления
-        if update_params["type"] not in updates:
-            raise ValueError("Обновление '%s' не существует!" % update_params["type"])
+        # проверка заданного типа обновления и его параметров
+        update_type = update_params.get("type")
+        if update_type not in UPDATE_TYPES:
+            raise ValueError('Unknown update type: {}'.format(update_type))
+        if update_type != "ручное":
+            user_schedule = update_params.get("schedule", list())
+            schedules = user_schedule if isinstance(user_schedule, list) else [user_schedule]
+            for schedule in schedules:
+                # проверка времени
+                if "time" in schedule and check_time(schedule["time"]):
+                    raise ValueError('Time "{}" has wrong format!'.format(schedule["time"]))
+                # проверка часовой зоны
+                if "time_zone" in schedule and schedule["time_zone"] not in time_zones:
+                    raise ValueError('Time zone "{}" does not exist!'.format(schedule["time_zone"]))
+                # проверка периода
+                if "type" in schedule and schedule["type"] not in UPDATE_PERIOD:
+                    raise ValueError('Нет периода: "{}"!'.format(schedule["type"]))
+                # проверка дня недели
+                if "week_day" in schedule and schedule["week_day"] not in WEEK:
+                    raise ValueError('Неверный день недели: "{}"!'.format(schedule["week_day"]))
+                # проверка номера дня в месяце
+                if "day" in schedule and schedule["day"] > 31:
+                    raise ValueError('Неверное число месяца: "{}"!'.format(schedule["day"]))
+
+        # проверки инкрементального обновления
+        if update_type == "инкрементальное" and not increment_dim:
+            raise ValueError('Please enter "increment_dim" param!')
+
+        # проверки интервального обновления
+        if update_type == "интервальное":
+            if not interval_dim:
+                raise ValueError('Please enter "interval_dim" param!')
+            if user_interval not in INTERVAL_MAP:
+                raise ValueError('No such interval: "{}"'.format(user_interval))
+            if user_interval == "с указанной даты":
+                if len(interval_borders) < 1:
+                    raise ValueError(
+                        'For the current update interval parameter "interval_borders" must have at least one element!')
+                _ = get_date(interval_borders[0])
+            if user_interval == "с и по указанную дату":
+                if len(interval_borders) < 2:
+                    raise ValueError(
+                        'For the current update interval parameter "interval_borders" must have at least two elements!')
+                if get_date(interval_borders[0]) > get_date(interval_borders[1]):
+                    raise ValueError('Start date must be greater than end date!')
 
         # проверка корректности параметров в словаре sql_params
         if (file_type != "excel") and (file_type != "csv"):
             if sql_params is None:
-                raise ValueError("If your sourse is sql: fill in param sql_params!\n\n"
-                                 "In other cases: it is wrong param file_type: %s\n\nIt can be only:\n"
-                                 "excel OR csv" % file_type)
-            if ("server" not in sql_params) or ("login" not in sql_params) or ("passwd" not in sql_params) \
-                    or ("sql_query" not in sql_params):
+                raise ValueError('If your sourse is sql: fill in param "sql_params"!\n\n'
+                                 'In other cases: it is wrong param "file_type": %s\n\nIt can be only:\n'
+                                 'excel OR csv' % file_type)
+            if not ({"server", "login", "passwd", "sql_query"} <= set(sql_params.keys())):
                 raise ValueError(
                     "Please check the following params names in sql_params:\n-server\n-login\n-passwd\n-sql_query")
 
-        if user_interval not in interval:
-            raise ValueError("No such interval: %s" % user_interval)
-
-        # проверка длины и отствия пробелов в имени источника
+        # проверка длины и отсутствия пробелов в имени источника
         if len(source_name) < 5:
             raise ValueError("Имя источника должно состоять из 5 и более символов!")
         if " " in source_name:
             raise ValueError("Знак <ПРОБЕЛ> не должен быть в Имени источника!")
 
-        if update_params["type"] != "ручное":
-            # проверка корректности введенной часовой зоны
-            if update_params["schedule"]["time_zone"] not in time_zones:
-                raise ValueError("Time zone %s does not exist!" % update_params["schedule"]["time_zone"])
-            # проверка периода, дня недели:
-            if update_params["schedule"]["type"] not in period:
-                raise ValueError("Нет периода: %s !" % update_params["schedule"]["type"])
-            if "week_day" in update_params["schedule"]:
-                if update_params["schedule"]["week_day"] not in week:
-                    raise ValueError("Неверный день недели: %s !" % update_params["schedule"]["week_day"])
-            if "day" in update_params["schedule"]:
-                if update_params["schedule"]["day"] > 31:
-                    raise ValueError("Неверный день месяца: %s !" % update_params["schedule"]["day"])
         self.func_name = 'create_sphere'
         return True
     elif func_name == "execute_olap_command":
