@@ -220,28 +220,37 @@ class Helper:
                 return self._raise_exception(ScenarioError, status_message, with_traceback=False)
         return count_of_requests, self.parse_result(result=progress, key="finished_steps_count")
 
-    def parse_result(self, result: Dict, key: str, nested_key: str = None) -> Any:
+    def parse_result(self, result: Dict, key: str, nested_key: str = None, default_value: Any = None) -> Any:
         """
         Парсит и проверяет на ошибки ответ в виде ['queries'][0]['command']['значение']['необязательное значение'].
         :param result: (Dict) нераспарсенный ответ от API.
         :param key: (str) ключ, значение которого нужно распарсить.
         :param nested_key: (str) вложенный ключ, значение которого нужно распарсить.
-        :return: (Dict) Значение заданного поля.
+        :param default_value: (Any) значение по-умолчанию для ключа в случае, если этот ключ отсутствует;
+            если при отсутствующем ключе данный параметр не будет задан, то будет сгенерирована ошибка.
+        :return: (Any) Значение заданного поля.
         """
-        base_error_msg = "ERROR while parsing response: ['queries'][0]['command']"
-        request_queries = result.get("queries")
-        request_queries = next(iter(request_queries))
+        base_error_msg = "Error while parsing response: ['queries'][0]['command']"
+        request_queries = next(iter(result.get("queries")))
         request_command = request_queries.get("command")
-        value = request_command.get(key)
-        if value is None:
-            error_msg = "{}['{}']".format(base_error_msg, key)
-            return self._raise_exception(ParseError, error_msg, with_traceback=False)
+
+        if key not in request_command:
+            if default_value is None:
+                error_msg = "{}['{}']".format(base_error_msg, key)
+                return self._raise_exception(ParseError, error_msg, with_traceback=False)
+            value = default_value
+        else:
+            value = request_command.get(key)
+
         if nested_key is not None:
-            nested_value = value.get(nested_key)
-            if nested_value is None:
+            if not isinstance(value, dict):
+                error_msg = "{}['{}'] is not dict!".format(base_error_msg, key)
+                return self._raise_exception(ParseError, error_msg, with_traceback=False)
+            if nested_key not in value:
                 error_msg = "{}['{}']['{}']".format(base_error_msg, key, nested_key)
                 return self._raise_exception(ParseError, error_msg, with_traceback=False)
-            return nested_value
+            return value.get(nested_key)
+
         return value
 
     def get_rows_cols(self, num_row: int = None, num_col: int = None) -> Dict:
